┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/statusbar/mountpointobservercache.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/statusbar/mountpointobservercache.h')
-rw-r--r--src/statusbar/mountpointobservercache.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/statusbar/mountpointobservercache.h b/src/statusbar/mountpointobservercache.h
index 425000645..8a1496d89 100644
--- a/src/statusbar/mountpointobservercache.h
+++ b/src/statusbar/mountpointobservercache.h
@@ -37,9 +37,9 @@ public:
static MountPointObserverCache* instance();
/**
* Returns a MountPointObserver for the given \a path. A new observer is created if necessary.
*/
- MountPointObserver* observerForPath(const QString& path);
+ MountPointObserver* observerForUrl(const QUrl& url);
private slots:
/**
@@ -48,8 +48,8 @@ private slots:
void slotObserverDestroyed(QObject* observer);
private:
- QHash<QString, MountPointObserver*> m_observerForMountPoint;
- QHash<QObject*, QString> m_mountPointForObserver;
+ QHash<QUrl, MountPointObserver*> m_observerForMountPoint;
+ QHash<QObject*, QUrl> m_mountPointForObserver;
QTimer* m_updateTimer;
friend class MountPointObserverCacheSingleton;
@@ -37,9 +37,9 @@ public:
static MountPointObserverCache* instance();
/**
- * Returns a MountPointObserver for the given \a path. A new observer is created if necessary.
+ * Returns a MountPointObserver for the given \a url. A new observer is created if necessary.
*/